@@ -13,6 +13,7 @@ import { useDispatch } from "react-redux";
 import { toggleSnackbar } from "../../../redux/explorer";
 import API from "../../../middleware/Api";
 import AlertDialog from "../Dialogs/Alert";
+import { useTranslation } from "react-i18next";
 
 const useStyles = makeStyles((theme) => ({
     root: {
@@ -34,6 +35,8 @@ const useStyles = makeStyles((theme) => ({
 }));
 
 export default function Access() {
+    const { t } = useTranslation("dashboard", { keyPrefix: "settings" });
+    const { t: tVas } = useTranslation("dashboard", { keyPrefix: "vas" });
     const classes = useStyles();
     const [loading, setLoading] = useState(false);
     const [options, setOptions] = useState({
@@ -112,7 +115,7 @@ export default function Access() {
             options: option,
         })
             .then(() => {
-                ToggleSnackbar("top", "right", "设置已更改", "success");
+                ToggleSnackbar("top", "right", t("saved"), "success");
             })
             .catch((error) => {
                 ToggleSnackbar("top", "right", error.message, "error");
@@ -125,17 +128,15 @@ export default function Access() {
     return (
         <div>
             <AlertDialog
-                title={"提示"}
-                msg={
-                    "Web Authn 需要您的站点启用 HTTPS，并确认 参数设置 - 站点信息 - 站点URL 也使用了 HTTPS 后才能开启。"
-                }
+                title={t("hint")}
+                msg={t("webauthnNoHttps")}
                 onClose={() => setHttpAlert(false)}
                 open={httpAlert}
             />
             <form onSubmit={submit}>
                 <div className={classes.root}>
                     <Typography variant="h6" gutterBottom>
-                        注册与登录
+                        {t("accountManagement")}
                     </Typography>
                     <div className={classes.formContainer}>
                         <div className={classes.form}>
@@ -151,10 +152,10 @@ export default function Access() {
                                             )}
                                         />
                                     }
-                                    label="允许新用户注册"
+                                    label={t("allowNewRegistrations")}
                                 />
                                 <FormHelperText id="component-helper-text">
-                                    关闭后，无法再通过前台注册新的用户
+                                    {t("allowNewRegistrationsDes")}
                                 </FormHelperText>
                             </FormControl>
                         </div>
@@ -172,10 +173,10 @@ export default function Access() {
                                             )}
                                         />
                                     }
-                                    label="邮件激活"
+                                    label={t("emailActivation")}
                                 />
                                 <FormHelperText id="component-helper-text">
-                                    开启后，新用户注册需要点击邮件中的激活链接才能完成。请确认邮件发送设置是否正确，否则激活邮件无法送达
+                                    {t("emailActivationDes")}
                                 </FormHelperText>
                             </FormControl>
                         </div>
@@ -193,10 +194,10 @@ export default function Access() {
                                             )}
                                         />
                                     }
-                                    label="注册验证码"
+                                    label={t("captchaForSignup")}
                                 />
                                 <FormHelperText id="component-helper-text">
-                                    是否启用注册表单验证码
+                                    {t("captchaForSignupDes")}
                                 </FormHelperText>
                             </FormControl>
                         </div>
@@ -214,10 +215,10 @@ export default function Access() {
                                             )}
                                         />
                                     }
-                                    label="登录验证码"
+                                    label={t("captchaForLogin")}
                                 />
                                 <FormHelperText id="component-helper-text">
-                                    是否启用登录表单验证码
+                                    {t("captchaForLoginDes")}
                                 </FormHelperText>
                             </FormControl>
                         </div>
@@ -235,10 +236,10 @@ export default function Access() {
                                             )}
                                         />
                                     }
-                                    label="找回密码验证码"
+                                    label={t("captchaForReset")}
                                 />
                                 <FormHelperText id="component-helper-text">
-                                    是否启用找回密码表单验证码
+                                    {t("captchaForResetDes")}
                                 </FormHelperText>
                             </FormControl>
                         </div>
@@ -266,11 +267,10 @@ export default function Access() {
                                             }}
                                         />
                                     }
-                                    label="Web Authn"
+                                    label={t("webauthn")}
                                 />
                                 <FormHelperText id="component-helper-text">
-                                    是否允许用户使用绑定的外部验证器登录，站点必须启动
-                                    HTTPS 才能使用。
+                                    {t("webauthnDes")}
                                 </FormHelperText>
                             </FormControl>
                         </div>
@@ -278,7 +278,7 @@ export default function Access() {
                         <div className={classes.form}>
                             <FormControl>
                                 <InputLabel htmlFor="component-helper">
-                                    默认用户组
+                                    {t("defaultGroup")}
                                 </InputLabel>
                                 <Select
                                     value={options.default_group}
@@ -302,7 +302,7 @@ export default function Access() {
                                     })}
                                 </Select>
                                 <FormHelperText id="component-helper-text">
-                                    用户注册后的初始用户组
+                                    {t("defaultGroupDes")}
                                 </FormHelperText>
                             </FormControl>
                         </div>
@@ -316,7 +316,7 @@ export default function Access() {
                         variant={"contained"}
                         color={"primary"}
                     >
-                        保存
+                        {t("save")}
                     </Button>
                 </div>
             </form>
