@@ -7,11 +7,12 @@ import MenuItem from "@material-ui/core/MenuItem";
 import Select from "@material-ui/core/Select";
 import { makeStyles } from "@material-ui/core/styles";
 import Typography from "@material-ui/core/Typography";
-import React, { useCallback, useEffect, useState } from "react";
+import React, { useCallback, useEffect,useMemo, useState } from "react";
 import { useDispatch } from "react-redux";
 import { useHistory } from "react-router";
 import { toggleSnackbar } from "../../../redux/explorer";
 import API from "../../../middleware/Api";
+import { useTranslation } from "react-i18next";
 
 const useStyles = makeStyles((theme) => ({
     root: {
@@ -32,6 +33,8 @@ const useStyles = makeStyles((theme) => ({
     },
 }));
 export default function UserForm(props) {
+    const { t } = useTranslation("dashboard", { keyPrefix: "user" });
+    const { t: tDashboard } = useTranslation("dashboard");
     const classes = useStyles();
     const [loading, setLoading] = useState(false);
     const [user, setUser] = useState(
@@ -44,6 +47,7 @@ export default function UserForm(props) {
                   Password: "", // 为空时只读
                   Status: "0", // 转换类型
                   GroupID: "2", // 转换类型
+                  TwoFactor: "",
               }
     );
     const [groups, setGroups] = useState([]);
@@ -93,7 +97,7 @@ export default function UserForm(props) {
                 ToggleSnackbar(
                     "top",
                     "right",
-                    "用户已" + (props.user ? "保存" : "添加"),
+                    props.user ? t("saved") : t("added"),
                     "success"
                 );
             })
@@ -105,20 +109,35 @@ export default function UserForm(props) {
             });
     };
 
+    const groupSelections = useMemo(
+        () =>
+            groups.map((v) => {
+                if (v.ID === 3) {
+                    return null;
+                }
+                return (
+                    <MenuItem key={v.ID} value={v.ID.toString()}>
+                        {v.Name}
+                    </MenuItem>
+                );
+            }),
+        [groups]
+    );
+
     return (
         <div>
             <form onSubmit={submit}>
                 <div className={classes.root}>
                     <Typography variant="h6" gutterBottom>
-                        {user.ID === 0 && "创建用户"}
-                        {user.ID !== 0 && "编辑 " + user.Nick}
+                        {user.ID === 0 && t("new")}
+                        {user.ID !== 0 && t("editUser", { nick: user.Nick })}
                     </Typography>
 
                     <div className={classes.formContainer}>
                         <div className={classes.form}>
                             <FormControl fullWidth>
                                 <InputLabel htmlFor="component-helper">
-                                    邮箱
+                                    {t("email")}
                                 </InputLabel>
                                 <Input
                                     value={user.Email}
@@ -132,7 +151,7 @@ export default function UserForm(props) {
                         <div className={classes.form}>
                             <FormControl fullWidth>
                                 <InputLabel htmlFor="component-helper">
-                                    昵称
+                                    {t("nick")}
                                 </InputLabel>
                                 <Input
                                     value={user.Nick}
@@ -145,7 +164,7 @@ export default function UserForm(props) {
                         <div className={classes.form}>
                             <FormControl fullWidth>
                                 <InputLabel htmlFor="component-helper">
-                                    密码
+                                    {t("password")}
                                 </InputLabel>
                                 <Input
                                     type={"password"}
@@ -154,7 +173,7 @@ export default function UserForm(props) {
                                     required={user.ID === 0}
                                 />
                                 <FormHelperText id="component-helper-text">
-                                    {user.ID !== 0 && "留空表示不修改"}
+                                    {user.ID !== 0 && t("passwordDes")}
                                 </FormHelperText>
                             </FormControl>
                         </div>
@@ -162,29 +181,17 @@ export default function UserForm(props) {
                         <div className={classes.form}>
                             <FormControl fullWidth>
                                 <InputLabel htmlFor="component-helper">
-                                    用户组
+                                    {t("group")}
                                 </InputLabel>
                                 <Select
                                     value={user.GroupID}
                                     onChange={handleChange("GroupID")}
                                     required
                                 >
-                                    {groups.map((v) => {
-                                        if (v.ID === 3) {
-                                            return null;
-                                        }
-                                        return (
-                                            <MenuItem
-                                                key={v.ID}
-                                                value={v.ID.toString()}
-                                            >
-                                                {v.Name}
-                                            </MenuItem>
-                                        );
-                                    })}
+                                    {groupSelections}
                                 </Select>
                                 <FormHelperText id="component-helper-text">
-                                    用户所属用户组
+                                    {t("groupDes")}
                                 </FormHelperText>
                             </FormControl>
                         </div>
@@ -192,22 +199,43 @@ export default function UserForm(props) {
                         <div className={classes.form}>
                             <FormControl fullWidth>
                                 <InputLabel htmlFor="component-helper">
-                                    状态
+                                    {t("status")}
                                 </InputLabel>
                                 <Select
                                     value={user.Status}
                                     onChange={handleChange("Status")}
                                     required
                                 >
-                                    <MenuItem value={"0"}>正常</MenuItem>
-                                    <MenuItem value={"1"}>未激活</MenuItem>
-                                    <MenuItem value={"2"}>被封禁</MenuItem>
+                                    <MenuItem value={"0"}>
+                                        {t("active")}
+                                    </MenuItem>
+                                    <MenuItem value={"1"}>
+                                        {t("notActivated")}
+                                    </MenuItem>
+                                    <MenuItem value={"2"}>
+                                        {t("banned")}
+                                    </MenuItem>
                                     <MenuItem value={"3"}>
-                                        超额使用被封禁
+                                        {t("bannedBySys")}
                                     </MenuItem>
                                 </Select>
                             </FormControl>
                         </div>
+
+                        <div className={classes.form}>
+                            <FormControl fullWidth>
+                                <InputLabel htmlFor="component-helper">
+                                    {t("2FASecret")}
+                                </InputLabel>
+                                <Input
+                                    value={user.TwoFactor}
+                                    onChange={handleChange("TwoFactor")}
+                                />
+                            </FormControl>
+                            <FormHelperText id="component-helper-text">
+                                {t("2FASecretDes")}
+                            </FormHelperText>
+                        </div>
                     </div>
                 </div>
                 <div className={classes.root}>
@@ -217,7 +245,7 @@ export default function UserForm(props) {
                         variant={"contained"}
                         color={"primary"}
                     >
-                        保存
+                        {tDashboard("settings.save")}
                     </Button>
                 </div>
             </form>
