@@ -1,6 +1,6 @@
 import React, { useState, useCallback, useEffect } from "react";
 import { makeStyles, Typography } from "@material-ui/core";
-import { useDispatch } from "react-redux";
+import { useDispatch, useSelector } from "react-redux";
 import Paper from "@material-ui/core/Paper";
 import Tabs from "@material-ui/core/Tabs";
 import Tab from "@material-ui/core/Tab";
@@ -21,6 +21,8 @@ import TimeAgo from "timeago-react";
 import Link from "@material-ui/core/Link";
 import { toggleSnackbar } from "../../redux/explorer";
 import Nothing from "../Placeholder/Nothing";
+import { useTranslation } from "react-i18next";
+import AppPromotion from "./AppPromotion";
 
 const useStyles = makeStyles((theme) => ({
     layout: {
@@ -53,10 +55,12 @@ const useStyles = makeStyles((theme) => ({
 }));
 
 export default function WebDAV() {
+    const { t } = useTranslation();
     const [tab, setTab] = useState(0);
     const [create, setCreate] = useState(false);
     const [accounts, setAccounts] = useState([]);
 
+    const appPromotion = useSelector((state) => state.siteConfig.app_promotion);
     const dispatch = useDispatch();
     const ToggleSnackbar = useCallback(
         (vertical, horizontal, msg, color) =>
@@ -67,12 +71,12 @@ export default function WebDAV() {
     const copyToClipboard = (text) => {
         if (navigator.clipboard) {
             navigator.clipboard.writeText(text);
-            ToggleSnackbar("top", "center", "已复制到剪切板", "success");
+            ToggleSnackbar("top", "center", t("setting.copied"), "success");
         } else {
             ToggleSnackbar(
                 "top",
                 "center",
-                "当前浏览器不支持，请手动复制",
+                t("setting.pleaseManuallyCopy"),
                 "warning"
             );
         }
@@ -141,7 +145,7 @@ export default function WebDAV() {
                 onClose={() => setCreate(false)}
             />
             <Typography color="textSecondary" variant="h4">
-                WebDAV
+                {t("navbar.connect")}
             </Typography>
             <Paper elevation={3} className={classes.content}>
                 <Tabs
@@ -151,16 +155,17 @@ export default function WebDAV() {
                     onChange={(event, newValue) => setTab(newValue)}
                     aria-label="disabled tabs example"
                 >
-                    <Tab label="账号管理" />
+                    <Tab label={t("setting.webdavAccounts")} />
+                    {appPromotion && <Tab label={t("setting.iOSApp")} />}
                 </Tabs>
                 <div className={classes.cardContent}>
                     {tab === 0 && (
                         <div>
                             <Alert severity="info">
-                                WebDAV的地址为：
-                                {window.location.origin + "/dav"}
-                                ；登录用户名统一为：{user.user_name}{" "}
-                                ；密码为所创建账号的密码。
+                                {t("setting.webdavHint", {
+                                    url: window.location.origin + "/dav",
+                                    name: user.user_name,
+                                })}
                             </Alert>
                             <TableContainer className={classes.tableContainer}>
                                 <Table
@@ -169,16 +174,20 @@ export default function WebDAV() {
                                 >
                                     <TableHead>
                                         <TableRow>
-                                            <TableCell>备注名</TableCell>
-                                            <TableCell>密码</TableCell>
-                                            <TableCell align="right">
-                                                根目录
+                                            <TableCell>
+                                                {t("setting.annotation")}
+                                            </TableCell>
+                                            <TableCell>
+                                                {t("login.password")}
                                             </TableCell>
                                             <TableCell align="right">
-                                                创建日期
+                                                {t("setting.rootFolder")}
                                             </TableCell>
                                             <TableCell align="right">
-                                                操作
+                                                {t("setting.createdAt")}
+                                            </TableCell>
+                                            <TableCell align="right">
+                                                {t("setting.action")}
                                             </TableCell>
                                         </TableRow>
                                     </TableHead>
@@ -202,7 +211,9 @@ export default function WebDAV() {
                                                         }
                                                         href={"javascript:void"}
                                                     >
-                                                        复制
+                                                        {t("copyToClipboard", {
+                                                            ns: "common",
+                                                        })}
                                                     </Link>
                                                 </TableCell>
                                                 <TableCell align="right">
@@ -211,7 +222,12 @@ export default function WebDAV() {
                                                 <TableCell align="right">
                                                     <TimeAgo
                                                         datetime={row.CreatedAt}
-                                                        locale="zh_CN"
+                                                        locale={t(
+                                                            "timeAgoLocaleCode",
+                                                            {
+                                                                ns: "common",
+                                                            }
+                                                        )}
                                                     />
                                                 </TableCell>
                                                 <TableCell align="right">
@@ -229,7 +245,7 @@ export default function WebDAV() {
                                     </TableBody>
                                 </Table>
                                 {accounts.length === 0 && (
-                                    <Nothing primary={"没有记录"} />
+                                    <Nothing primary={t("setting.listEmpty")} />
                                 )}
                             </TableContainer>
                             <Button
@@ -238,10 +254,11 @@ export default function WebDAV() {
                                 variant="contained"
                                 color="secondary"
                             >
-                                创建新账号
+                                {t("setting.createNewAccount")}
                             </Button>
                         </div>
                     )}
+                    {tab === 1 && <AppPromotion />}
                 </div>
             </Paper>
         </div>
