@@ -1,19 +1,11 @@
 /* eslint-disable @typescript-eslint/no-var-requires */
 const proxy = require("http-proxy-middleware");
 module.exports = function (app) {
-    app.use(
-        "/api",
+    ["/api","/custom","/f"].map(p=>app.use(
+        p,
         proxy({
             target: "http://localhost:5212",
             changeOrigin: true,
         })
-    );
-
-    app.use(
-        "/custom",
-        proxy({
-            target: "http://localhost:5212",
-            changeOrigin: true,
-        })
-    );
+    ))
 };
