@@ -3,7 +3,7 @@ package conf
 import (
 	"github.com/cloudreve/Cloudreve/v3/pkg/util"
 	"github.com/go-ini/ini"
-	"gopkg.in/go-playground/validator.v9"
+	"github.com/go-playground/validator/v10"
 )
 
 // database 数据库
@@ -26,6 +26,8 @@ type system struct {
 	Debug         bool
 	SessionSecret string
 	HashIDSalt    string
+	GracePeriod   int    `validate:"gte=0"`
+	ProxyHeader   string `validate:"required_with=Listen"`
 }
 
 type ssl struct {
@@ -36,6 +38,7 @@ type ssl struct {
 
 type unix struct {
 	Listen string
+	Perm   uint32
 }
 
 // slave 作为slave存储端配置
@@ -60,6 +63,8 @@ type cors struct {
 	AllowHeaders     []string
 	AllowCredentials bool
 	ExposeHeaders    []string
+	SameSite         string
+	Secure           bool
 }
 
 var cfg *ini.File
@@ -84,13 +89,13 @@ func Init(path string) {
 		}, defaultConf)
 		f, err := util.CreatNestedFile(path)
 		if err != nil {
-			util.Log().Panic("无法创建配置文件, %s", err)
+			util.Log().Panic("Failed to create config file: %s", err)
 		}
 
 		// 写入配置文件
 		_, err = f.WriteString(confContent)
 		if err != nil {
-			util.Log().Panic("无法写入配置文件, %s", err)
+			util.Log().Panic("Failed to write config file: %s", err)
 		}
 
 		f.Close()
@@ -98,7 +103,7 @@ func Init(path string) {
 
 	cfg, err = ini.Load(path)
 	if err != nil {
-		util.Log().Panic("无法解析配置文件 '%s': %s", path, err)
+		util.Log().Panic("Failed to parse config file %q: %s", path, err)
 	}
 
 	sections := map[string]interface{}{
@@ -113,7 +118,7 @@ func Init(path string) {
 	for sectionName, sectionStruct := range sections {
 		err = mapSection(sectionName, sectionStruct)
 		if err != nil {
-			util.Log().Panic("配置文件 %s 分区解析失败: %s", sectionName, err)
+			util.Log().Panic("Failed to parse config section %q: %s", sectionName, err)
 		}
 	}
 
